@@ -65,10 +65,20 @@ def SetAlarm():
             action_run.flags |= alarm.ACTION_WHEN_TRIGGERED | alarm.ACTION_TYPE_EXEC
             action_run.command = data.AlternativeAlarm
 
+        try:
+            print event
+            print event.appid
+#            print event.message
+            print event.alarm_time
+
+        except:
+            print "Could not print event data"
 
         data.AlarmID = alarm.add_event(event)
+        print "AlarmID:", data.AlarmID
 
         event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
+
         print "* Alarm will go off on:", time.ctime(event.trigger)
     else:
         print "* Will not set alarm, Maemo interface not available"
