@@ -162,7 +162,7 @@ def WriteRecord():
     d=str(records.arrData[0][records.Index-1]) + ", " +  \
         str(records.arrData[1][records.Index-1]) + ", " +  \
         str(records.arrData[2][records.Index-1]) + ", " +  \
-        str(records.arrData[3][records.Index-1]) + ", "
+        str(records.arrData[3][records.Index-1])
 
     data.RecordFile.write(d+"\n")
 #    if(data.debug==True): print "Write to file:",d
@@ -382,13 +382,16 @@ def LoadRecord():
     records.Index=0
     try: #get data
         for line in file:
-            d=string.split(line[:-1], ", ")
+    #        d=string.split(line[:-1], ", ")
+    #        print line
+            d=string.split(line, ",")
             records.arrData[0][records.Index]=d[0] #time
             records.arrData[1][records.Index]=int(d[1]) #X
             records.arrData[2][records.Index]=int(d[2]) #Y
             if(records.SWversion<1.8): #workaround for old files (versions <1.8 had only X and Y axis stored)
                 records.arrData[3][records.Index]=0 #Z
             else:
+#                print d[3]
                 records.arrData[3][records.Index]=int(d[3]) #Z
 
             records.Index=records.Index+1
@@ -398,7 +401,7 @@ def LoadRecord():
                 records.statusID="ARRAY_FULL"
                 break
     except:
-        print "File is corrupted"
+        print "File is corrupted!!!"
         records.status=_("File is corrupted or not compatible")
         records.statusID="FILE_CORRUPTED"
         file.close()
